<?php
define('IMWB_VIDEOPRESS_VERSION', '1.5');

require_once ( get_template_directory() . '/theme-options.php' );
require_once ( get_template_directory() . '/video-sitemap.php' );
require_once ( get_template_directory() . '/csscolor.php' );
require_once ( get_template_directory() . '/widgets.php');

add_action("after_setup_theme", "imwb_videopress_setup");
add_action("widgets_init", "imwb_videopress_widgets_init");
add_action('wp_head','imwb_videopress_head',50);
add_action( 'wp_footer', 'imwb_videopress_footer', 50 );
add_filter('imwb_videopress_filter_content', 'imwb_videopress_content_filter', 10, 2);
	
if (!is_admin()) {
   $imwb_videopress_swfobject = "";
   add_action('wp_enqueue_scripts', 'imwb_videopress_enqueue_scripts');
   add_action( 'pre_get_posts', 'imwb_videopress_posts_query' );
} 
else {
   
   // Theme Update Check
   require_once('theme-admin-update.php');
   // Initialize Update Object
   $themeUpdate = new IMWB_VideoPress_Update('imwb_videopress');	
   $themeUpdate->lastUpdateCheck();
   if($themeUpdate->update['latest_version'] > IMWB_VIDEOPRESS_VERSION)
      add_action('admin_notices', 'imwb_videopress_admin_update_notice');
      
   add_action( 'wp_ajax_rating', 'imwb_videopress_update_rating' );
   add_action( 'wp_ajax_nopriv_rating', 'imwb_videopress_update_rating' );
}

   function imwb_videopress_admin_update_notice(){
      GLOBAL $themeUpdate;
       echo '<div class="updated">'.$themeUpdate->update['after_plugin_row'].'</div>';
   }
	
	function imwb_videopress_get_blogtitle() {
		wp_title("|", true, "right");
		bloginfo("name");
	}
	
	function imwb_videopress_setup() {

      add_theme_support("automatic-feed-links");
      add_theme_support("post-thumbnails");
      set_post_thumbnail_size( 200, 150, true );
      
      $bgDefaults = array(
      	'default-color' => '000000',
      	'default-image' => get_template_directory_uri() . '/images/background.png'
      );
      
      $headerDefaults = array(
      	'default-image'          => '',
      	'random-default'         => false,
      	'width'                  => 400,
      	'height'                 => 50,
      	'flex-height'            => false,
      	'flex-width'             => false,
      	'default-text-color'     => 'CB2027',
      	'header-text'            => true,
      	'uploads'                => true,
      	'admin-head-callback'    => 'imwb_videopress_admin_header_style'
      );
      
      if ( imwb_videopress_is_wp_version( '3.4' ) ) {
      	add_theme_support( 'custom-background', $bgDefaults); 
      	add_theme_support( 'custom-header', $headerDefaults);
      }
      else {
         define( 'HEADER_TEXTCOLOR', $headerDefaults['default-text-color'] );
         define( 'HEADER_IMAGE', '' );
         define( 'HEADER_IMAGE_WIDTH', $headerDefaults['width'] );
         define( 'HEADER_IMAGE_HEIGHT', $headerDefaults['height'] );
         add_custom_background( 'imwb_videopress_custom_background_callback' );
         add_custom_image_header( $headerDefaults['wp-head-callback'], $headerDefaults['admin-head-callback'], $headerDefaults['admin-preview-callback'] );
         
      }
      
		add_image_size( 'imwb-videopress-video-thumb', 200, 150 );
		add_image_size( 'imwb-videopress-video-preview', 600, 400 );
		
		// This theme uses wp_nav_menu() in one location.
		register_nav_menu( 'cvp_page_menu', 'CVP Header Menu' );
	
	}
	
	function imwb_videopress_enqueue_scripts() {
   	wp_enqueue_script( 'swfobject' );
   	wp_enqueue_script( 'jquery' );
   	wp_enqueue_script( 'jquery_masonry', get_template_directory_uri() .'/scripts/jquery.masonry.min.js', array('jquery') );
	}
	
	function imwb_videopress_get_option($element) {
		
      $defaults = imwb_videopress_get_default_theme_options();
		
		$imwb_videopress_current_options = get_option('imwb_videopress_theme_options', $defaults);
	
		if(isset($imwb_videopress_current_options[$element]) && $imwb_videopress_current_options[$element] == '#')
			return stripslashes($defaults[$element]); 		
      else if(isset($imwb_videopress_current_options[$element]))
			return stripslashes($imwb_videopress_current_options[$element]); 
		else if ( isset($defaults[$element]) ) 
			return stripslashes($defaults[$element]); 
		else
			return false;
	}
	
	
	function imwb_videopress_widgets_init() {
      
		register_sidebar(array(
			 "name"			=> "Main Sidebar"
			,"id"			=> "sidebar-widget"
			,"before_widget"=> '<li id="%1$s" class="widget-container %2$s">'
			,"after_widget"	=> "</li>"
			,"before_title"	=> "<h3 class=\"widget-title\">"
			,"after_title"	=> "</h3>"
		));
		
		register_sidebar(array(
			 "name"			=> "Single Post Sidebar"
			,"id"			=> "sidebar-post-widget"
			,"description" => "An optional widget area for your signle post page"
			,"before_widget"=> '<li id="%1$s" class="widget-container %2$s">'
			,"after_widget"	=> "</li>"
			,"before_title"	=> "<h3 class=\"widget-title\">"
			,"after_title"	=> "</h3>"
		));
		
		register_sidebar( array(
			 "name" => "Footer Area One"
			,"id" => "sidebar-footer-1"
			,"description" => "An optional widget area for your site footer"
         ,"before_widget"=> '<li id="%1$s" class="widget-container %2$s">'
         ,"after_widget"	=> "</li>"
         ,"before_title"	=> "<h3 class=\"widget-title\">"
         ,"after_title"	=> "</h3>"
		) );
	
		register_sidebar( array(
      	 "name" => "Footer Area Two"
      	,"id" => "sidebar-footer-2"
      	,"description" => "An optional widget area for your site footer"
         ,"before_widget"=> '<li id="%1$s" class="widget-container %2$s">'
         ,"after_widget"	=> "</li>"
         ,"before_title"	=> "<h3 class=\"widget-title\">"
         ,"after_title"	=> "</h3>"
      ) );
	
		register_sidebar( array(
      	 "name" => "Footer Area Three"
      	,"id" => "sidebar-footer-3"
      	,"description" => "An optional widget area for your site footer"
         ,"before_widget"=> '<li id="%1$s" class="widget-container %2$s">'
         ,"after_widget"	=> "</li>"
         ,"before_title"	=> "<h3 class=\"widget-title\">"
         ,"after_title"	=> "</h3>"
      ) );

      $active_widgets = get_option( 'sidebars_widgets' );

		if (!empty( $active_widgets['nag-bar-widget'])) 
		      return;

      // Note that widgets are numbered. We need a counter:
      $counter = 1;
      // Add a 'demo' widget to the top sidebar …
      $active_widgets['nag-bar-widget'][0] = 'text-' . $counter;
      $widget_content[ $counter ] = array ( 'title' => '', 'text' => '<p>This is a widget area - If you go to "Appearance" in your WP-Admin you can change the content of this box in "Widgets", or you can remove this box completely under "Theme Options"</p>' );
      
      update_option( 'widget_text', $widget_content );
      
      // Now save the $active_widgets array.
      update_option( 'sidebars_widgets', $active_widgets );
      
      	
	}
	
	/**
	 * Count the number of footer sidebars to enable dynamic classes for the footer
	 */
	function imwb_videopress_footer_sidebar_class() {
		$count = 0;
	
		if ( is_active_sidebar( 'sidebar-footer-1' ) )
			$count++;
	
		if ( is_active_sidebar( 'sidebar-footer-2' ) )
			$count++;
	
		if ( is_active_sidebar( 'sidebar-footer-3' ) )
			$count++;
	
		$class = '';
	
		switch ( $count ) {
			case '1':
				$class = 'one';
				break;
			case '2':
				$class = 'two';
				break;
			case '3':
				$class = 'three';
				break;
		}
	
		if ( $class )
			echo 'class="' . $class . '"';
	}
	
	function imwb_videopress_content_filter($content, $postImageSrc)
	{
	    if($postImageSrc == '')
   	    $content = preg_replace('#(<[/]?img.*>)#U', '', $content); 
	    else
	       $content = preg_replace('#<\s*img.+src=["\']'.preg_quote($postImageSrc).'["\'].*>#Ui', '', $content); 
	       
	    return $content;
	}
	
	function imwb_videopress_strip_embed_code($text) {
	    $tags = array('iframe','object','embed','param');
	    foreach ($tags as $tag){
	        while(preg_match('/<'.$tag.'(|\W[^>]*)>(.*)<\/'. $tag .'>/iusU', $text, $found)){
	            $text = str_replace($found[0],$found[2],$text);
	        }
	    }

       $text =  preg_replace('/(<('.join('|',$tags).')(|\W.*)\/>)/iusU', '', $text);
       
       return $text;
	}
	
	function imwb_videopress_strip_video_shortcodes($text) {
		$tags = array('evp', 'youtube','dailymotion','vimeo','metacafe');
      
      foreach ($tags as $tag){
         $text =  preg_replace('/\['.$tag.'(|\W.*)\](.*)\[\/'. $tag .'\]/iusU', '', $text);
      }
	   
	   return $text;
	}
   
	function imwb_videopress_get_logo() {
	   
//	   if(imwb_videopress_get_option('logourl') != '')
//   		return '<a href="'.home_url( '/' ).'" alt=""> <img src="'.imwb_videopress_get_option('logourl').'" /> </a>';
//   	else 
//   	   return '<a href="'.home_url( '/' ).'" alt=""><h1 id="blog_title">'.get_bloginfo('name').'</h1></a><h2 id="blog_tagline">'.get_bloginfo('description').'</h2>';

      $text_color = get_header_textcolor();
      $header_image = get_header_image();

      if ( $text_color && $text_color != 'blank' )
      	$text_style = ' style="color:#' . $text_color . '"';
      else
      	$text_style = '';  
      
      if(!empty($header_image) && !empty($text_style)) {
         echo '<div id="logo" style="background-image: URL('.get_header_image().')">'; 
         echo '<a href="'.home_url( '/' ).'" alt=""><h1 id="blog_title" '.$text_style.'>'.get_bloginfo('name').'</h1></a><h2 id="blog_tagline" '.$text_style.'>'.get_bloginfo('description').'</h2>';
      }
      else if(!empty($header_image) && empty($text_style)) {
          echo '<div id="logo">';
          echo '<a href="'.home_url( '/' ).'" alt=""> <img src="'.get_header_image().'" /> </a>';
      }
      else if(empty($header_image) && !empty($text_style)) {
         echo '<div id="logo">';
         echo '<a href="'.home_url( '/' ).'" alt=""><h1 id="blog_title" '.$text_style.'>'.get_bloginfo('name').'</h1></a><h2 id="blog_tagline" '.$text_style.'>'.get_bloginfo('description').'</h2>';    
      }
      else {
         echo '<div id="logo">';
      }
      
      echo '</div>';
      
	}
	
 /**
  * Works out the default video lost order and returns it
  */	
 function imwb_videopress_list_order() {
 
    $option = isset($_REQUEST['so']) ? $_REQUEST['so'] : 'def';
    
    // Use option settings is not already set
    if($option == 'def') {
    
       switch(imwb_videopress_get_option('listorder')) {
          case '0': $option = 'rav';
                    break;
          case '1': $option = 'trv';
                    break;
          case '2': $option = 'mvv';
                    break;        
       }
    }
    
    return $option;
 }

 /**
  * Alters the main home page query to sort by Most Rated/Viewed if selected
  */
 function imwb_videopress_posts_query($query) {
 
    if( $query->is_main_query() && is_home()) {
    
       $option = imwb_videopress_list_order();

       switch ( strtolower($option) ) {
          case 'mvv': $query->set( 'orderby', 'meta_value_num' );
                      $query->set( 'meta_key', '_imwb_videopress_post_video_views' );
        	             $query->set( 'order', 'DESC' );
        	             break;
          case 'trv': $query->set( 'orderby', 'meta_value_num' );
                      $query->set( 'meta_key', '_imwb_videopress_post_video_rating' );
         	          $query->set( 'order', 'DESC' );
         	          break;  	             
      }
    }
 }
	
 /**
  * Post Meta Data Box and Custom fields
  *
  */
  
  add_action( 'load-post.php', 'imwb_videopress_meta_boxes_setup' );
  add_action( 'load-post-new.php', 'imwb_videopress_meta_boxes_setup' );
  
  function imwb_videopress_meta_boxes_setup() {
  
  	   /* Add meta boxes on the 'add_meta_boxes' hook. */
  	   add_action( 'add_meta_boxes', 'imwb_videopress_add_post_meta_boxes' );
  	   add_action( 'save_post', 'imwb_videopress_save_post_video_meta' );
  }
  
  function imwb_videopress_add_post_meta_boxes() {
  
  	add_meta_box(
  		'imwb_videopress-post-video',			// Unique ID
  		esc_html__( 'Video', 'imwb_videopress' ),		// Title
  		'imwb_videopress_post_video_meta_box',		// Callback function
  		'post',					// Admin page (or post type)
  		'normal',					// Context
  		'high'					// Priority
  	);
  	
  }
  
  if ( in_array( basename( $_SERVER['PHP_SELF'] ), array( 'post-new.php', 'post.php') ) ) {
     add_action( 'admin_head', 'imwb_videopress_meta_boxes_head' );
  }
  
  function imwb_videopress_meta_boxes_head() {
  ?>
    <style>

       .imwbvp_video_thumbnail {
          border: 1px solid #DFDFDF;
          width: 200px;
          float: right;
          top:  3px;
          right: 5px;
       }
       .imwbvp_video_thumbnail span {
          text-align: center;
          background-color: #E9E9E9;
          display: block;
          padding: 3px;
       }
        .imwbvp_video_thumbnail .image {
          width: 200px;
          height: 150px;
          text-align: center;
          font-weight: bold;
       }
    
    </style>
    <script>
    ( function( $ ) {
    
       $(document).ready(function() {
          $hints = Array();
          $hints['D'] = 'Please enter the URL where the video can be viewed. <b>E.G.</b> http://www.dailymotion.com/video/xi9v9h_slow-mo-of-giant-bubbles-on-stinson-beach-ca_tech';
          $hints['F'] = 'Please enter the URL to the video file. <b>E.G.</b> http://yoursite.com/video.mp4';
          $hints['M'] = 'Please enter the URL where the video can be viewed. <b>E.G.</b> http://www.metacafe.com/watch/8748970/the_amazing_spider_man/';
          $hints['V'] = 'Please enter the URL where the video can be viewed. <b>E.G.</b> http://vimeo.com/40132261';
          $hints['Y'] = 'Please enter the URL where the video can be viewed. <b>E.G.</b> http://www.youtube.com/watch?v=SqtXkv0jigQ';
                  
          $('input[name="imwb_videopress_post_video-type"]').change(function() {
              $('#imwb_videopress_post_video-label').html($hints[$(this).val()]);
          });
          
          $('#imwb_videopress_post_video-label').html($hints[$('input[name="imwb_videopress_post_video-type"]:checked').val()])
  
       });
    
    } ) ( jQuery );
    </script>
  <?php
  }
  
  function imwb_videopress_post_video_meta_box( $object, $box ) { ?>
  
  	<?php wp_nonce_field( basename( __FILE__ ), 'imwb_videopress-post-video_nonce' );
      $videoType = get_post_meta( $object->ID, 'imwb_videopress_post_video_type', true );
      if(empty($videoType)) $videoType = 'F';
  	 ?>
  	 <?php if(imwb_videopress_get_option('autogenthumbs') == '1') { ?>
  	   		<div class="imwbvp_video_thumbnail">
  	   		 <span>Video Thumbnail</span>
  	   		 <div class="image">
  	 <?php
  	   		    $img = imwb_videopress_get_the_post_thumbnail();
  	   		    if(empty($img))
  	   		       echo '<br>Thumbnail generation will be attempted on next save/update';
  	   		    else 
  	             echo $img;
  	 ?> 
  	   		 </div>
  	   		</div>
  	 <?php } ?> 
  	<p>
  	   <input type="radio" name="imwb_videopress_post_video-type" id="imwb_videopress_post_video-type" value="F" <?php checked( $videoType, 'F' ); ?>> Video File&nbsp;&nbsp;
  	   <input type="radio" name="imwb_videopress_post_video-type" id="imwb_videopress_post_video-type" value="Y" <?php checked( $videoType, 'Y' ); ?>> You Tube&nbsp;&nbsp;
  	   <input type="radio" name="imwb_videopress_post_video-type" id="imwb_videopress_post_video-type" value="V" <?php checked( $videoType, 'V' ); ?>> Vimeo&nbsp;&nbsp;
  	   <input type="radio" name="imwb_videopress_post_video-type" id="imwb_videopress_post_video-type" value="D" <?php checked( $videoType, 'D' ); ?>> DailyMotion&nbsp;&nbsp;
  	   <input type="radio" name="imwb_videopress_post_video-type" id="imwb_videopress_post_video-type" value="M" <?php checked( $videoType, 'M' ); ?>> Metacafe
  	   <br><br>
  		<label id="imwb_videopress_post_video-label" for="imwb_videopress_post_video-url">Link URL:</label><br>
  		<input type="text" name="imwb_videopress_post_video-url" id="imwb_videopress_post_video-url" value="<?php echo esc_attr( get_post_meta( $object->ID, 'imwb_videopress_post_video_url', true ) ); ?>" size="100" />
 	</p> 		
 	<p>
 	<label id="imwb_videopress_post_video-label" for="imwb_videopress_post_video-views">View Count:</label>	<input type="text" name="imwb_videopress_post_video-views" id="imwb_videopress_post_video-views" value="<?php echo esc_attr( get_post_meta( $object->ID, '_imwb_videopress_post_video_views', true ) ); ?>" size="10" />
 	<label id="imwb_videopress_post_video-label" for="imwb_videopress_post_video-rating">Rating (From 0 to 5):</label>	<input type="text" name="imwb_videopress_post_video-rating" id="imwb_videopress_post_video-rating" value="<?php echo esc_attr( imwb_videopress_get_rating($object->ID ) ); ?>" size="10" />
 	</p>
  	 		<div style="clear: both"></div>
  <?php }
  
  function imwb_videopress_save_post_video_meta($post_id) {
  
    // verify if this is an auto save routine. 
    // If it is our form has not been submitted, so we dont want to do anything
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
        return;
        
  	/* Verify the nonce before proceeding. */
  	if ( !isset( $_POST['imwb_videopress-post-video_nonce'] ) || !wp_verify_nonce( $_POST['imwb_videopress-post-video_nonce'], basename( __FILE__ ) ) )
  		return $post_id;
  
   // Check permissions
   if ( 'page' == $_POST['post_type'] ) 
         return;
   else
   {
     if ( !current_user_can( 'edit_post', $post_id ) )
         return;
   }
   
   if(wp_is_post_revision($post_id))
      return;
    
  	$vtChanged = true;
  	
  	/* Get the posted data and sanitize it for use as an HTML class. */
  	$vt_meta_value = ( isset( $_POST['imwb_videopress_post_video-type'] ) ?  $_POST['imwb_videopress_post_video-type'] : '' );
  	
	/* Get the meta key. */
	$meta_key = 'imwb_videopress_post_video_type';

	/* Get the meta value of the custom field key. */
	$meta_value = get_post_meta( $post_id, $meta_key, true );

	/* If a new meta value was added and there was no previous value, add it. */
	if ( $vt_meta_value && '' == $meta_value ) 
		add_post_meta( $post_id, $meta_key, $vt_meta_value, true );

	/* If the new meta value does not match the old value, update it. */
	elseif ( $vt_meta_value && $vt_meta_value != $meta_value ) 
		update_post_meta( $post_id, $meta_key, $vt_meta_value );
   
	/* If there is no new meta value but an old value exists, delete it. */
	elseif ( '' == $vt_meta_value && $meta_value ) 
		delete_post_meta( $post_id, $meta_key, $meta_value );  

	/* Nothing changed */
	else 
   	$vtChanged = false;   	
   	
  	$vuChanged = true;
   	
	/* Get the posted data and sanitize it for use as an HTML class. */
	$vu_meta_value = ( isset( $_POST['imwb_videopress_post_video-url'] ) ? $_POST['imwb_videopress_post_video-url'] : '' );

  	/* Get the meta key. */
  	$meta_key = 'imwb_videopress_post_video_url';
  
  	/* Get the meta value of the custom field key. */
  	$meta_value = get_post_meta( $post_id, $meta_key, true );

  	/* If a new meta value was added and there was no previous value, add it. */
  	if ( $vu_meta_value && '' == $meta_value )
  		add_post_meta( $post_id, $meta_key, $vu_meta_value, true );

  	/* If the new meta value does not match the old value, update it. */
  	elseif ( $vu_meta_value && $vu_meta_value != $meta_value ) 
  		update_post_meta( $post_id, $meta_key, $vu_meta_value );
   
  	/* If there is no new meta value but an old value exists, delete it. */
  	elseif ( '' == $vu_meta_value && $meta_value ) 
  		delete_post_meta( $post_id, $meta_key, $meta_value );
  	
   /* Nothing changed */
   else 
   	$vuChanged = false;
   	               
   /* Do we need to generate a thumbnail */
   if(($vtChanged || $vuChanged) && imwb_videopress_get_option('autogenthumbs') == '1') 
         imwb_videopress_generate_thumbnail($post_id, $vt_meta_value, $vu_meta_value );
         
   /* Set the video id */
   if($vtChanged) { // If the video type changed then remove any existing id's
      delete_post_meta( $post_id , 'imwb_ctc_dailymotion_id');
      delete_post_meta( $post_id , 'imwb_ctc_metacafe_id');
      delete_post_meta( $post_id , 'imwb_ctc_youtube_id');
      delete_post_meta( $post_id , 'imwb_ctc_vimeo_id');
   }
   
   $video_id = imwb_videopress_get_video_id($vt_meta_value, $vu_meta_value);
   switch ( $vt_meta_value ) {
      case 'D': update_post_meta( $post_id , 'imwb_ctc_dailymotion_id', trim($video_id) );
                break;
      case 'M': update_post_meta( $post_id , 'imwb_ctc_metacafe_id', trim($video_id) );
    	          break;    		    	          
   	case 'Y': update_post_meta( $post_id , 'imwb_ctc_youtube_id', trim($video_id) );
   		       break;
      case 'V': update_post_meta( $post_id , 'imwb_ctc_vimeo_id', trim($video_id) );     		
   		       break;
   } 
         
   /* Views */
   $vc_meta_value = ( isset( $_POST['imwb_videopress_post_video-views'] ) ? $_POST['imwb_videopress_post_video-views'] : '0' );
   if(empty($vc_meta_value) || !is_numeric($vc_meta_value))
      $vc_meta_value = '0';
      
   if ( !update_post_meta( $post_id, '_imwb_videopress_post_video_views', $vc_meta_value ) ) 
      add_post_meta( $post_id, '_imwb_videopress_post_video_views', $vc_meta_value, true );
      
   /* Rating */
   $vr_meta_value = ( isset( $_POST['imwb_videopress_post_video-rating'] ) ? $_POST['imwb_videopress_post_video-rating'] : '0' );
   if(empty($vr_meta_value) || !is_numeric($vr_meta_value))
      $vr_meta_value = '0';
   
   if($vr_meta_value < 0 || $vr_meta_value > 5)
      $vr_meta_value = '0';
      
   // * get current rating
   $rating_value = imwb_videopress_get_rating($post_id);   
   
   // If Changed then reset */
   if($vr_meta_value != $rating_value) {
            
         if ( !update_post_meta( $post_id, '_imwb_videopress_post_video_score', $vr_meta_value ) ) 
            add_post_meta( $post_id, '_imwb_videopress_post_video_score', $vr_meta_value, true );   
            
         if ( !update_post_meta( $post_id, '_imwb_videopress_post_video_count', '1' ) ) 
               add_post_meta( $post_id, '_imwb_videopress_post_video_count', '1', true );  
               
         if ( !update_post_meta( $post_id, '_imwb_videopress_post_video_rating', $vr_meta_value ) ) 
               add_post_meta( $post_id, '_imwb_videopress_post_video_rating', $vr_meta_value, true );  
   }

  }
  
  // checks is WP is at least a certain version (makes sure it has sufficient comparison decimals
  function imwb_videopress_is_wp_version( $is_ver ) {
      $wp_ver = explode( '.', get_bloginfo( 'version' ) );
      $is_ver = explode( '.', $is_ver );
      for( $i=0; $i<=count( $is_ver ); $i++ )
          if( !isset( $wp_ver[$i] ) ) array_push( $wp_ver, 0 );
   
      foreach( $is_ver as $i => $is_val )
          if( $wp_ver[$i] < $is_val ) return false;
      return true;
  }
  
  function imwb_videopress_custom_background_callback() {
  
      /* Get the background image. */
      $image = get_background_image();
      
      /* If there's an image, just call the normal WordPress callback. We won't do anything here. */
      if ( !empty( $image ) ) {
      	_custom_background_cb();
      	return;
      }
      
      /* Get the background color. */
      $color = get_background_color();
      
      /* If no background color, return. */
      if ( empty( $color ) ) {
         echo '<style type="text/css">body { background: url('.get_template_directory_uri() . '/images/background.png); }</style>';
      }
      
      /* Use 'background' instead of 'background-color'. */
      $style = "background: #{$color};";
      
      ?>
      <style type="text/css">body { <?php echo trim( $style ); ?> }</style>
      <?php
  
  }
  
  /**
   * Styles the header image displayed on the Appearance > Header admin panel.
   *
   */
  function imwb_videopress_admin_header_style() {
  ?>
  	<style type="text/css">
  	.appearance_page_custom-header #headimg {
  		border: none;
  		font-size: 10px;
  		text-align: left;
  		 top: 2px;
  		min-height: 40px;
  	}
  	#headimg h1,
  	#desc {
  		font-family: "helvetica neue",arial,sans-serif;
  	}
  	#headimg h1 {
  		font-size: 2em; margin: 2px 0 0 0;
  	}
  	#headimg h1 a {
  		text-decoration: none;
  	}
  	#desc {
      font-size: 1.5em; margin: 0;color: #8C7E7E;
  	}
  	<?php
  		// If the user has set a custom color for the text use that
  		if ( get_header_textcolor() != HEADER_TEXTCOLOR ) :
  	?>
  		#site-title a,
  		#site-description {
  			color: #<?php echo get_header_textcolor(); ?>;
  		}
  	<?php endif; ?>
  	#headimg img {
  		max-width: 520px;
  		height: auto;
  		width: 100%;
  	}
  	</style>
  <?php
  }
  
  function imwb_videopress_head() {
  
     imwb_videopress_open_graph_head();
?>     
<script type="text/javascript">
// <![CDATA[
	var imwbvp_flashvars = {};
//	var imwbvp_params = { wmode: "opaque", allowfullscreen: "true", allowscriptaccess: "always", allownetworking: "internal" };
	var imwbvp_params = { wmode: "opaque", allowfullscreen: "true", allowscriptaccess: "always"};
	var imwbvp_attributes = {};
	var imwbvp_expressinstall = "<?php echo get_template_directory_uri(); ?>/assets/expressinstall.swf";
	var imwbvp_ajaxurl = '<?php echo admin_url( 'admin-ajax.php' );?>';
// ]]>
</script>
<?php  
  }
  
  function imwb_videopress_footer() {
      global $imwb_videopress_swfobject;

      if ( is_feed() || empty($imwb_videopress_swfobject) )
         return;
    
  		$content = "\n<script type=\"text/javascript\">\n";
  
  		$content .= '	swfobject.embedSWF("' . ( $imwb_videopress_swfobject['url'] ) . '", "' . $imwb_videopress_swfobject['objectid'] . '", "600", "400", "10", imwbvp_expressinstall, ';
  
  			if ( empty($imwb_videopress_swfobject['flashvars']) || !is_array($imwb_videopress_swfobject['flashvars']) ) {
  				$content .= 'imwbvp_flashvars';
  			} else {
  				$content .= '{ ';
  
  				//$imwb_videopress_swfobject['flashvars'] = array_merge( array( 'wmode' => 'opaque', 'allowfullscreen' => 'true', 'allowscriptaccess' => 'always' ), $imwb_videopress_swfobject['flashvars'] );
  				$flashvars = array();
  
  				foreach ( $imwb_videopress_swfobject['flashvars'] as $property => $value ) {
  					if ( false === $value )
  						continue;
  
  					$flashvars[] = '"' . esc_js( $property ). '": "' . esc_js( $value ) . '"';
  				}
  
  				$content .= implode( ', ', $flashvars );
  				$content .= ' }';
  			}
  
  			$content .= ", imwbvp_params, imwbvp_attributes);\n";
  		$content .= "</script>\n";
  
  		// Clear outputted calls
  		$imwb_videopress_swfobject = "";
  
  		echo $content;
  
  }
  
  // build ogp meta
  function imwb_videopress_open_graph_head() {
  
  	global $post;
  
	echo "\n<!-- Open Graph protocol meta data -->\n";
		
	// Which URL we need
	if (is_home() || is_front_page() || is_search() || is_category() )
		$ogp_url = get_bloginfo( 'url' );
	else 
		$ogp_url = 'http' . (is_ssl() ? 's' : '') . "://".$_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
	
	echo '<meta property="og:url" content="' . esc_url($ogp_url) . '">' . "\n";
	
	// Site Title
	echo '<meta property="og:title" content="' . esc_attr( wp_title("|", false, "right").get_bloginfo( 'name' ) ) . '">' . "\n";
	
	//  Site Name
	echo '<meta property="og:site_name" content="' . get_bloginfo( 'name' ) . '">' . "\n";
	
	// Descriptions
	if ( is_single() || is_page() ) {
		if ( has_excerpt( $post->ID ) )
			$ogp_description = strip_tags( get_the_excerpt( $post->ID ) );
		else 
			$ogp_description = str_replace( "\r\n", ' ' , substr( strip_tags( strip_shortcodes( $post->post_content ) ), 0, 160 ) );
	} 
	else 
		$ogp_description = get_bloginfo( 'description' );
	
	echo '<meta property="og:description" content="' . esc_attr( $ogp_description ). '">' . "\n";
	
	// OG Type
	if ( is_single() || is_page()) {
		$ogp_type = 'article';
	} else {
		$ogp_type = 'website';
	}
	echo '<meta property="og:type" content="' . esc_attr($ogp_type) . '">' . "\n";
	
	// Find/output any images for use in the OGP tags
	$wpfbogp_images = array();
		
	// Image details
   if ( is_single() || is_page()) {
	
  /* 	$postImage = imwb_videopress_get_the_image(Array('image_class' => 'tack_entry_img', "link_to_post" => false, 'echo' => false, 'size' => '', 'use_image_scan_link' => true));
	   preg_match_all( '|<img.*?src=[\'"](.*?)[\'"].*?>|i', $postImage, $matches );
   	$postImageSrc = $matches[1][0];
   */
   	 $postImageSrc = imwb_videopress_post_thumbnail_img_src();  	
		echo '<meta property="og:image" content="' . esc_url($postImageSrc) . '">' . "\n";
	}
	else 
		// No images were outputted because they have no default image (at the very least)
		echo "<!-- Could not find an image! -->\n"; 
	
	// Locale
	echo '<meta property="og:locale" content="' . strtolower( esc_attr( get_locale() ) ) . '">' . "\n";
	echo "<!--  Open Graph protocol meta data  -->\n";

  }
  
  function imwb_videopress_the_video($post_id) {
  
     $video_type = get_post_meta( $post_id, 'imwb_videopress_post_video_type', true );
     $video_url = get_post_meta( $post_id, 'imwb_videopress_post_video_url', true );
     
     if(empty($video_url))
        return '';
     
     $the_video = '';
     
     switch ( $video_type ) {
      case 'D':
         $the_video =  imwb_videopress_video_dailymotion($video_url, $post_id);
         break;
     	case 'F':
     		$the_video =  imwb_videopress_video_file($video_url, $post_id);
     		break;
      case 'M':
      	$the_video =  imwb_videopress_video_metacafe($video_url, $post_id);
      	break;     		
     	case 'Y':
     		$the_video =  imwb_videopress_video_youtube($video_url, $post_id);
     		break;
      case 'V':
	      $the_video =  imwb_videopress_video_vimeo($video_url, $post_id);     		
     		break;
     }   
     
     return $the_video;
  }
  
   /*
    * Extract the ID from the video url
    */
   function imwb_videopress_get_video_id($video_type, $video_url) {
  
      // YouTube
      if($video_type == 'Y') {
     		// If a URL was passed
     		if ( 'http://' == substr( $video_url, 0, 7 ) || 'https://' == substr( $video_url, 0, 8 )) {
     
            if ( FALSE !== stristr( $video_url, 'youtu.be' ) ) {
     			   preg_match( '#https?://youtu\.be/([\w-]+)#i', $video_url, $matches );
     				if ( empty($matches) || empty($matches[1]) )
     					return '';
     
               return $matches[1];
     			}
     			// Normal video URL
     			else {
     				preg_match( '#https?://(www.youtube|youtube|[A-Za-z]{2}.youtube)\.com/(watch\?v=|w/\?v=|\?v=)([\w-]+)(.*?)#i', $video_url, $matches );
     				if ( empty($matches) || empty($matches[3]) ) 
     				   return '';
     
     				return $matches[3];
     			}
     		}
     		// If a URL wasn't passed, assume a video ID 
     		else {
     		   return $video_url;
     		}
     }
     // Vimeo
     elseif($video_type == 'V') {
     		// If a URL was passed
     		if ( 'http://' == substr( $video_url, 0, 7 ) ) {
     			preg_match( '#http://(www.vimeo|vimeo)\.com(/|/clip:)(\d+)(.*?)#i', $video_url, $matches );
     			if ( empty($matches) || empty($matches[3]) ) 
     			   return '';     
     			
     			return $matches[3];
     		}
     		// If a URL wasn't passed, assume a video ID 
     		else {
     			return $video_url;
     		}
     
     }
     // DailyMotion 
     elseif($video_type == 'D') {
     		if ( 'http://' == substr( $video_url, 0, 7 ) ) {
     			preg_match( '#http://(www.dailymotion|dailymotion)\.com/(.+)/([0-9a-zA-Z]+)\_(.*?)#i', $video_url, $matches );
     			if ( empty($matches) || empty($matches[3]) ) 
     			   return '';
     
     			return $matches[3];
     		}
     	   // If a URL wasn't passed, assume a video ID 
     		else {
     			return $video_url;
     		}
     }
     // Metacafe
     elseif($video_type == 'M') {
     		// If a URL was passed
     		if ( 'http://' == substr( $video_url, 0, 7 ) ) {
     			preg_match( '#http://(www.metacafe|metacafe)\.com/watch/(.*?)/(.*?)#i', $video_url, $matches );
     			if ( empty($matches) || empty($matches[2]) ) 
     			   return '';
     
     			return $matches[2];
     		}
     		// If a URL wasn't passed, assume a video ID was passed instead
     		else {
     			return $video_url;
     		}
   
    }
     
     return '';
  }
  
  function imwb_videopress_video_file($video_url, $post_id) {
  
     $video_type = wp_check_filetype($video_url);
     
      // ID is required for multiple videos to work
     	$id = 'video_id_'.rand();
      
      // See what filetype Supplied
      $flv_source = '';
     	$mp4_source = ''; 
  		$webm_source = '';     
  		$ogg_source = '';
  		
      switch(strtolower($video_type['ext'])) {
         case 'flv':  $flv_source = '<source src="'.$video_url.'" type=\'video/flv\' />';
                      break;
         case 'mp4':
         case 'm4v':  $mp4_source = '<source src="'.$video_url.'" type=\'video/mp4\' />';
                      break;
         case 'webm': $webm_source = '<source src="'.$video_url.'" type=\'video/webm; codecs="vp8, vorbis"\' />';
                      break;
         case 'ogg':  $ogg_source = '<source src="'.$video_url.'" type=\'video/ogg; codecs="theora, vorbis"\' />';
                      break;
      }
            

      $poster_attribute = ' poster="'.esc_html__(imwb_videopress_post_thumbnail_img_src($post_id, 'imwb-videopress-video-preview')).'"';
      
      // Preload the video
      $preload_attribute = 'preload="auto"';
      
      // Autoplay the video?
      if (imwb_videopress_get_option('autoplay') == '1')
      	$autoplay_attribute = " autoplay";
      else
      	$autoplay_attribute = "";
        
      
      $videojs = <<<_end_
      
      <!-- Begin Video.js -->
      <video id="{$id}" class="video-js vjs-default-skin" width="600px" height="400px" {$poster_attribute} controls {$preload_attribute}{$autoplay_attribute} data-setup="{}">
         {$flv_source}
      	{$mp4_source}
      	{$webm_source}
      	{$ogg_source}
      </video>
      <!-- End Video.js -->
      
_end_;
      
      return $videojs;
  }
  
  function imwb_videopress_video_youtube($video_url, $post_id) {

     $video_id = imwb_videopress_get_video_id('Y', $video_url);

  	  // Setup the parameters
  	  $color1 = $color2 = $border = $autoplay = $loop = $showsearch = $showinfo = $hd = '';
  
     $color1 = '&color1=0x666666';
     $color2 = '&color2=0xEFEFEF';
	  $border = '&border=1';
	  $autoplay = '&autoplay='.imwb_videopress_get_option('autoplay');
	  $hd = '&hd=1';  
  	  $objectid = 'video_id_'.rand();
  	  $modestbranding = '&modestbranding='.imwb_videopress_get_option('ytmodestbrand');
 
      return '<iframe class="youtube-player" type="text/html" width="100%" height="100%" src="http://www.youtube.com/embed/'.$video_id.'?rel=0&fs=1&showsearch=0&showinfo=0'.$autoplay.$hd.$border.$color1.$color2.$modestbranding.'" frameborder="0">
      	  </iframe>';
  	}
  	
  	function imwb_videopress_video_vimeo($video_url, $post_id) {
  	 
  	    $video_id = imwb_videopress_get_video_id('V', $video_url);

  	    $objectid = 'video_id_'.rand();
  	    $autoplay = '&amp;autoplay='.imwb_videopress_get_option('autoplay');
  	    
  	    return '<span style="width:100%;height:100%;"><iframe id="' . $objectid . '" src="http://player.vimeo.com/video/'.$video_id.'?title=0&amp;byline=0&amp;portrait=0&amp;color=f20511'.$autoplay.'" width="100%" height="100%" frameborder="0" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe> </span>';
  	
  	}
  	
 	function imwb_videopress_video_dailymotion($video_url, $post_id) {

 	   $video_id = imwb_videopress_get_video_id('D', $video_url);
 	   $objectid = 'video_id_'.rand();
 	   
 	   $autoplay = '&autoPlay='.imwb_videopress_get_option('autoplay');
 	   
 	   return '<iframe frameborder="0" width="100%" height="100%" src="http://www.dailymotion.com/embed/video/' . $video_id . '?logo=0&hideInfos=1'.$autoplay.'"></iframe>';
 	   
 	   
 	}
 	
 	function imwb_videopress_video_metacafe($video_url, $post_id) {
      global $imwb_videopress_swfobject;
      
      $video_id = imwb_videopress_get_video_id('M', $video_url);
      $objectid = 'video_id_'.rand(); 	
      $autoplay = imwb_videopress_get_option('autoplay') == '0' ? 'no' : 'yes';
      
      $imwb_videopress_swfobject = array( 'width' => '100%', 'height' => '100%', 'url' => 'http://www.metacafe.com/fplayer/' . $video_id . '/imwb_videopress_player.swf', 'flashvars' => array('playerVars=autoPlay' => $autoplay),
         'objectid' => $objectid  );
      
      return '<span style="width:100%;height:100%;"><span id="' . $objectid . '"><a href="http://www.metacafe.com/watch/' . $video_id . '/">http://www.metacafe.com/watch/' . $video_id . '/</a></span></span>';
 	}
  	
  	/* 
  	 * Thumbnail Functions
  	 */

   function imwb_videopress_the_post_thumbnail ( $post_id = null, $width = '200px', $height = '140px' ) {
      echo imwb_videopress_get_the_post_thumbnail($post_id, $width, $height);
   
   }
   
   function imwb_videopress_get_the_post_thumbnail ( $post_id = null, $width = '200px', $height = '140px' ) {
   
      // Get the post ID if none is provided
      if ( $post_id == null OR $post_id == '' ) $post_id = get_the_ID();
      
      $image_src = imwb_videopress_post_thumbnail_img_src ( $post_id);
      
      if(empty($image_src))
         return '';
      
      $attr = apply_filters( 'the_title', get_post_field( 'post_title', $post_id ) );
   
      return sprintf('<img src="%s" width="%s" height="%s" title="%s" alt="%s">', $image_src, $width, $height,  $attr, $attr);
   
   }
   
   function imwb_videopress_post_thumbnail_img_src ( $post_id = null, $size = 'imwb-videopress-video-thumb' ) {
   
      // Get the post ID if none is provided
      if ( $post_id == null OR $post_id == '' ) $post_id = get_the_ID();
   
      // If featured image set, use that one
      if(has_post_thumbnail($post_id)) {
         $post_thumbnail_id = get_post_thumbnail_id( $post_id );
         $image_attributes =  wp_get_attachment_image_src($post_thumbnail_id, $size );
         return $image_attributes[0];
      }
         
      
      // If Thumbnail attached then use that one
      if( ( $thumbnail_meta = get_post_meta( $post_id, '_video_thumbnail', true ) ) != '' ) {
      	return $thumbnail_meta;
      }
      
      // Else use default image
      
      return  get_template_directory_uri() .'/images/default.jpg';
   
   }
   
   function imwb_videopress_generate_thumbnail($post_id, $video_type, $video_url) {

      // Remove any current thumbnail
     	delete_post_meta( $post_id, '_video_thumbnail' );
     	  	   
  	   if(empty($video_url)) return;
  	   
  	   $video_thumbnail = '';
  	   
      $video_id = imwb_videopress_get_video_id($video_type, $video_url);

  	   /* Video file */
  	   if($video_type == 'F')
  	      $video_thumbnail = ''; // Yeah one day
  	   
  	   /* YouTube Video */
  	   elseif ($video_type == 'Y') 
  	      $video_thumbnail = 'http://img.youtube.com/vi/' . $video_id . '/0.jpg';
  	      
  	   /* Viemo Video */
  	   elseif ($video_type == 'V' ){
  	   
     	   $response = wp_remote_get( 'http://vimeo.com/api/v2/video/' . $video_id . '.php' );
     	   if( is_wp_error( $response ) ) {
     	      $video_thumbnail = '';  
     	   } else {
            $output = unserialize( $response['body'] );
            $video_thumbnail = $output[0]['thumbnail_large'];
            if(!isset($video_thumbnail))
               $video_thumbnail = $output[0]['thumbnail_medium'];
     	   }
  	   }
  	   
  	   /* DailyMotion Video */
  	   elseif ($video_type == 'D' ){
  	   
  	      $response = wp_remote_get( 'https://api.dailymotion.com/video/' . $video_id . '?fields=thumbnail_url' );
  	      if( is_wp_error( $response ) ) {
  	         $video_thumbnail = '';  
  	      } else {
  	       $output = json_decode( $response['body']  );
  	       $video_thumbnail = strtok($output->thumbnail_url, '?');
  	      }
  	   }
      /* Metacafe Video */
      elseif ($video_type == 'M' ){

         $response = fetch_feed('http://www.metacafe.com/api/item/' . $video_id . '/');
         if( is_wp_error( $response ) ) {
            $video_thumbnail = '';  
         } else {
           $item = $response->get_item(0);
           $enclosure = $item->get_enclosure();
           $video_thumbnail = strtok($enclosure->get_thumbnail(), '?');
         }
      }
      
      // See if need to store the image locally 
      if(imwb_videopress_get_option('storethumbs') == '1' && !empty($video_thumbnail)) {
      
         $response = wp_remote_get($video_thumbnail);
         if( !is_wp_error( $response ) ) {
            $upload = wp_upload_bits( basename( $video_thumbnail ), null, $response['body'] );
            $video_thumbnail = $upload['url'];
         }      
      
      }
        	   
      add_post_meta( $post_id, '_video_thumbnail', $video_thumbnail, true );
               
   }
   
   /*
    * Page Numbers & Navigation Functions
    */
    function imwb_videopress_page_numbers($range = 4) {
    	global $wp_query;
     
    	$big = 999999999; // This needs to be an unlikely integer
      $pages = $wp_query->max_num_pages;
      $paged = max( 1, get_query_var('paged'));
     
    	// For more options and info view the docs for paginate_links()
    	// http://codex.wordpress.org/Function_Reference/paginate_links
    	$paginate_links = paginate_links( array(
    		'base' => str_replace( $big, '%#%', get_pagenum_link($big) ),
    		'current' => $paged,
    		'total' => $pages,
    		'mid_size' => 5
    	) );
     
    	// Display the pagination if more than one page is found
    	if ( $paginate_links ) {
    	   echo '<div class="pagination_wrapper">';
    		echo '<div class="pagination"><span>Page '.$paged.' of '.$pages.'</span>';
    		echo $paginate_links;
    		echo '</div>';
    		echo '</div>';
    	}
    }   
    
    /**
     * Display the language string for the number of views the current post has.
     *
     */
    function imwb_videopress_views_number( $zero = false, $one = false, $more = false, $post_id = null) {
    
    	// Get the post ID if none is provided
    	if ( $post_id == null OR $post_id == '' ) $post_id = get_the_ID();
    
    	$number = get_post_meta( $post_id, '_imwb_videopress_post_video_views', true );
    	if(empty($number)) {
         $number = 0;
         add_post_meta( $post_id, '_imwb_videopress_post_video_views', $number, true );  
      }
    	if ( $number > 1 )
    		$output = str_replace('%', number_format_i18n($number), ( false === $more ) ? __('% Views') : $more);
    	elseif ( $number == 0 )
    		$output = ( false === $zero ) ? __('No Views') : $zero;
    	else // must be one
    		$output = ( false === $one ) ? __('1 View') : $one;
    
    	echo $output;
    } 
    
    function imwb_videopress_inc_views($post_id = null){
       // Get the post ID if none is provided
       if ( $post_id == null OR $post_id == '' ) $post_id = get_the_ID();
       
       $views = get_post_meta( $post_id, '_imwb_videopress_post_video_views', true );
       if(empty($views))
          $views = 1;
       else
          $views++;
       
       if ( !update_post_meta( $post_id, '_imwb_videopress_post_video_views', $views ) ) 
          add_post_meta( $post_id, '_imwb_videopress_post_video_views', $views, true );
    
    }
    
    function imwb_videopress_get_rating($post_id = null) {
       // Get the post ID if none is provided
       if ( $post_id == null OR $post_id == '' ) $post_id = get_the_ID();   
       
       $count = get_post_meta( $post_id, '_imwb_videopress_post_video_count', true );
       if(empty($count))
          $count = 1;

      $score = get_post_meta( $post_id, '_imwb_videopress_post_video_score', true );
      if(empty($score))
         $score = 0;
         
      $rating = get_post_meta( $post_id, '_imwb_videopress_post_video_rating', true );
      if(empty($rating)) {
         $rating = 0;
         add_post_meta( $post_id, '_imwb_videopress_post_video_rating', $rating, true );  
      }
         
      $avgRating = round($score/$count, 0);
      
      if($avgRating <> $rating) {
         if ( !update_post_meta( $post_id, '_imwb_videopress_post_video_rating', $avgRating ) ) 
            add_post_meta( $post_id, '_imwb_videopress_post_video_rating', $avgRating, true );  
      }   
      
      return $avgRating; 
    }
    
    function imwb_videopress_update_rating() {
       $post_id = intval($_POST['idBox']);
       $rate = floatval($_POST['rate']);
       
       $count = get_post_meta( $post_id, '_imwb_videopress_post_video_count', true );
       if(empty($count))
          $count = 0;
       
       $score = get_post_meta( $post_id, '_imwb_videopress_post_video_score', true );
       if(empty($score))
          $score = 0;
          
       $count++;
       $score+=$rate;
       
       if ( !update_post_meta( $post_id, '_imwb_videopress_post_video_score', $score ) ) 
          add_post_meta( $post_id, '_imwb_videopress_post_video_score', $score, true );   
           
       if ( !update_post_meta( $post_id, '_imwb_videopress_post_video_count', $count ) ) 
             add_post_meta( $post_id, '_imwb_videopress_post_video_count', $count, true ); 
             
      $avgRating = round($score/$count, 0);

      if ( !update_post_meta( $post_id, '_imwb_videopress_post_video_rating', $avgRating ) ) 
         add_post_meta( $post_id, '_imwb_videopress_post_video_rating', $avgRating, true );                        
             
       $aResponse['message'] = 'Your rate has been successfuly recorded. Thanks for your rate :)';
        
       echo json_encode($aResponse);
      die();
    }
  
   /*
    * RSS Feed functions
    *
    */
    add_action('rss2_ns', 'imwb_videopress_yahoo_media_tag');
    add_action('rss_item', 'imwb_videopress_feed_item');
    add_action('rss2_item', 'imwb_videopress_feed_item');
    add_filter('the_excerpt_rss', 'imwb_videopress_feed_content');
    add_filter('the_content_feed', 'imwb_videopress_feed_content');
    
    function imwb_videopress_yahoo_media_tag() {
    	echo 'xmlns:media="http://search.yahoo.com/mrss/"';
    }
    
    function imwb_videopress_feed_item($content) {
		global $post;
		
    	$image_url = imwb_videopress_post_thumbnail_img_src ($post->ID);
    	    	
    	if (!empty($image_url)) {   
    		echo '<enclosure url="' . $image_url . '" type="image/jpg" />';				
			echo '<media:content url="'.$image_url.'" width="200" height="140" medium="image" type="'.image_type_to_mime_type($type).'" />';
    	}
    }
    
    function imwb_videopress_feed_content($content) {
       global $post;

       $image_src = imwb_videopress_post_thumbnail_img_src ( $post->ID);

       if(empty($image_src))
          return $content;
                 
       $img = sprintf('<img src="%s" width="200px" height="140px" style="float:left; margin-right: 10px;">', $image_src);
       $content = '' . $img . '' . $content;    
       
       return $content;
    }
?>